@@ -14,9 +14,16 @@
 #' str_c("ba", str_dup("na", 0:5))
 str_dup <- function(string, times) {
   string <- check_string(string)
-
-  strings <- mlply(cbind(x = string, times), rep.int)
-  output <- unlist(llply(strings, str_c, collapse = ""))
+  
+  # Use data frame to do recycling
+  data <- data.frame(string, times)
+  n <- nrow(data)
+  string <- data$string
+  times <- data$times
+  
+  output <- unlist(lapply(seq_len(n), function(i){ 
+    paste(rep.int(string[i], times[i]), collapse = "")
+  }))
 
   names(output) <- names(string)
   output
